@@ -12,25 +12,22 @@
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QDir>
+#include <QGridLayout>
 #include <QLabel>
-#include <QPushButton>
 #include <QMap>
+#include <QPushButton>
 #include <QSettings>
-#include <QSharedPointer>
 #include <QStandardPaths>
 #include <private/qlocale_p.h>
-#include <QGridLayout>
 
-#include <klanguagebutton.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLanguageButton>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // Believe it or not we can't use KConfig from here
 // (we need KConfig during QCoreApplication ctor which is too early for it)
 // So we cooked a QSettings based solution
-typedef QSharedPointer<QSettings> QSettingsPtr;
-
-static QSettingsPtr localeOverridesSettings()
+static std::unique_ptr<QSettings> localeOverridesSettings()
 {
     const QString configPath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
     const QDir configDir(configPath);
@@ -38,24 +35,23 @@ static QSettingsPtr localeOverridesSettings()
         configDir.mkpath(QStringLiteral("."));
     }
 
-    return QSettingsPtr(new QSettings(configPath + QLatin1String("/klanguageoverridesrc"), QSettings::IniFormat));
+    return std::make_unique<QSettings>(configPath + QLatin1String("/klanguageoverridesrc"), QSettings::IniFormat);
 }
 
 static QByteArray getApplicationSpecificLanguage(const QByteArray &defaultCode = QByteArray())
 {
-    QSettingsPtr settings = localeOverridesSettings();
+    std::unique_ptr<QSettings> settings = localeOverridesSettings();
     settings->beginGroup(QStringLiteral("Language"));
     return settings->value(qAppName(), defaultCode).toByteArray();
 }
 
 namespace KDEPrivate
 {
-
 Q_COREAPP_STARTUP_FUNCTION(initializeLanguages)
 
 void setApplicationSpecificLanguage(const QByteArray &languageCode)
 {
-    QSettingsPtr settings = localeOverridesSettings();
+    std::unique_ptr<QSettings> settings = localeOverridesSettings();
     settings->beginGroup(QStringLiteral("Language"));
 
     if (languageCode.isEmpty()) {
@@ -74,13 +70,13 @@ void initializeLanguages()
         if (languages.isEmpty()) {
             qputenv("LANGUAGE", languageCode);
         } else {
-            qputenv("LANGUAGE", languageCode + ':' + languages);
+            qputenv("LANGUAGE", QByteArray(languageCode + ':' + languages));
         }
         // Ideally setting the LANGUAGE would change the default QLocale too
         // but unfortunately this is too late since the QCoreApplication constructor
         // already created a QLocale at this stage so we need to set the reset it
         // by triggering the creation and destruction of a QSystemLocale
-        // this is highly dependant on Qt internals, so may break, but oh well
+        // this is highly dependent on Qt internals, so may break, but oh well
         QSystemLocale *dummy = new QSystemLocale();
         delete dummy;
     }
@@ -97,17 +93,12 @@ struct LanguageRowData {
     KLanguageButton *languageButton;
     QPushButton *removeButton;
 
-    void setRowWidgets(
-        QLabel *label,
-        KLanguageButton *languageButton,
-        QPushButton *removeButton
-    )
+    void setRowWidgets(QLabel *label, KLanguageButton *languageButton, QPushButton *removeButton)
     {
         this->label = label;
         this->languageButton = languageButton;
         this->removeButton = removeButton;
     }
-
 };
 
 class KSwitchLanguageDialogPrivate
@@ -115,7 +106,7 @@ class KSwitchLanguageDialogPrivate
 public:
     KSwitchLanguageDialogPrivate(KSwitchLanguageDialog *parent);
 
-    KSwitchLanguageDialog *p; //parent class
+    KSwitchLanguageDialog *p; // parent class
 
     /**
         Fills language button with names of languages for which given application has translation.
@@ -140,13 +131,12 @@ public:
 /*************************** KSwitchLanguageDialog **************************/
 
 KSwitchLanguageDialog::KSwitchLanguageDialog(QWidget *parent)
-    : QDialog(parent),
-      d(new KSwitchLanguageDialogPrivate(this))
+    : QDialog(parent)
+    , d(new KSwitchLanguageDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Configure Language"));
 
-    QVBoxLayout *topLayout = new QVBoxLayout;
-    setLayout(topLayout);
+    QVBoxLayout *topLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(i18n("Please choose the language which should be used for this application:"), this);
     topLayout->addWidget(label);
@@ -177,17 +167,14 @@ KSwitchLanguageDialog::KSwitchLanguageDialog(QWidget *parent)
 
     QPushButton *addLangButton = new QPushButton(i18nc("@action:button", "Add Fallback Language"), this);
     addLangButton->setToolTip(i18nc("@info:tooltip", "Adds one more language which will be used if other translations do not contain a proper translation."));
-    connect(addLangButton, &QPushButton::clicked,
-            this, &KSwitchLanguageDialog::slotAddLanguageButton);
+    connect(addLangButton, &QPushButton::clicked, this, &KSwitchLanguageDialog::slotAddLanguageButton);
     addButtonHorizontalLayout->addWidget(addLangButton);
     addButtonHorizontalLayout->addStretch();
 
     topLayout->addStretch(10);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
-    buttonBox->setStandardButtons(QDialogButtonBox::Ok
-                                  | QDialogButtonBox::Cancel
-                                  | QDialogButtonBox::RestoreDefaults);
+    buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults);
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok), KStandardGuiItem::ok());
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::cancel());
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::RestoreDefaults), KStandardGuiItem::defaults());
@@ -197,8 +184,7 @@ KSwitchLanguageDialog::KSwitchLanguageDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KSwitchLanguageDialog::slotOk);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-    connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked,
-            this, &KSwitchLanguageDialog::slotDefault);
+    connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KSwitchLanguageDialog::slotDefault);
 }
 
 KSwitchLanguageDialog::~KSwitchLanguageDialog()
@@ -208,7 +194,7 @@ KSwitchLanguageDialog::~KSwitchLanguageDialog()
 
 void KSwitchLanguageDialog::slotAddLanguageButton()
 {
-    //adding new button with en_US as it should always be present
+    // adding new button with en_US as it should always be present
     d->addLanguageButton(QStringLiteral("en_US"), d->languageButtons.isEmpty());
 }
 
@@ -260,21 +246,21 @@ void KSwitchLanguageDialog::languageOnButtonChanged(const QString &languageCode)
 void KSwitchLanguageDialog::slotOk()
 {
     QStringList languages;
-
-    for (auto *languageButton : qAsConst(d->languageButtons)) {
+    languages.reserve(d->languageButtons.size());
+    for (auto *languageButton : std::as_const(d->languageButtons)) {
         languages << languageButton->current();
     }
 
     if (d->applicationLanguageList() != languages) {
         QString languageString = languages.join(QLatin1Char(':'));
-        //list is different from defaults or saved languages list
+        // list is different from defaults or saved languages list
         setApplicationSpecificLanguage(languageString.toLatin1());
 
         KMessageBox::information(
             this,
-            i18n("The language for this application has been changed. The change will take effect the next time the application is started."), //text
-            i18nc("@title:window", "Application Language Changed"), //caption
-            QStringLiteral("ApplicationLanguageChangedWarning") //dontShowAgainName
+            i18n("The language for this application has been changed. The change will take effect the next time the application is started."), // text
+            i18nc("@title:window", "Application Language Changed"), // caption
+            QStringLiteral("ApplicationLanguageChangedWarning") // dontShowAgainName
         );
     }
 
@@ -291,12 +277,11 @@ void KSwitchLanguageDialog::slotDefault()
     QString language = QString::fromLatin1(getApplicationSpecificLanguage("en_US"));
 
     if (defaultLanguages != (QStringList() << language)) {
-
         KMessageBox::information(
             this,
-            i18n("The language for this application has been changed. The change will take effect the next time the application is started."), //text
-            i18n("Application Language Changed"), //caption
-            QStringLiteral("ApplicationLanguageChangedWarning") //dontShowAgainName
+            i18n("The language for this application has been changed. The change will take effect the next time the application is started."), // text
+            i18n("Application Language Changed"), // caption
+            QStringLiteral("ApplicationLanguageChangedWarning") // dontShowAgainName
         );
     }
 
@@ -305,11 +290,10 @@ void KSwitchLanguageDialog::slotDefault()
 
 /************************ KSwitchLanguageDialogPrivate ***********************/
 
-KSwitchLanguageDialogPrivate::KSwitchLanguageDialogPrivate(
-    KSwitchLanguageDialog *parent)
+KSwitchLanguageDialogPrivate::KSwitchLanguageDialogPrivate(KSwitchLanguageDialog *parent)
     : p(parent)
 {
-    //NOTE: do NOT use "p" in constructor, it is not fully constructed
+    // NOTE: do NOT use "p" in constructor, it is not fully constructed
 }
 
 static bool stripCountryCode(QString *languageCode)
@@ -325,19 +309,19 @@ static bool stripCountryCode(QString *languageCode)
 void KSwitchLanguageDialogPrivate::fillApplicationLanguages(KLanguageButton *button)
 {
     const QLocale cLocale(QLocale::C);
-    QSet<QString> insertedLanguges;
+    QSet<QString> insertedLanguages;
 
     const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
     for (const QLocale &l : allLocales) {
         if (l != cLocale) {
             QString languageCode = l.name();
-            if (!insertedLanguges.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
+            if (!insertedLanguages.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
                 button->insertLanguage(languageCode);
-                insertedLanguges << languageCode;
+                insertedLanguages << languageCode;
             } else if (stripCountryCode(&languageCode)) {
-                if (!insertedLanguges.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
+                if (!insertedLanguages.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
                     button->insertLanguage(languageCode);
-                    insertedLanguges << languageCode;
+                    insertedLanguages << languageCode;
                 }
             }
         }
@@ -392,8 +376,7 @@ void KSwitchLanguageDialogPrivate::addLanguageButton(const QString &languageCode
 
     languageButton->setCurrentItem(languageCode);
 
-    QObject::connect(languageButton, &KLanguageButton::activated,
-                     p, &KSwitchLanguageDialog::languageOnButtonChanged);
+    QObject::connect(languageButton, &KLanguageButton::activated, p, &KSwitchLanguageDialog::languageOnButtonChanged);
 
     LanguageRowData languageRowData;
     QPushButton *removeButton = nullptr;
@@ -401,13 +384,12 @@ void KSwitchLanguageDialogPrivate::addLanguageButton(const QString &languageCode
     if (!primaryLanguage) {
         removeButton = new QPushButton(i18nc("@action:button", "Remove"), p);
 
-        QObject::connect(removeButton, &QPushButton::clicked,
-                         p, &KSwitchLanguageDialog::removeButtonClicked);
+        QObject::connect(removeButton, &QPushButton::clicked, p, &KSwitchLanguageDialog::removeButtonClicked);
     }
 
-    languageButton->setToolTip(primaryLanguage
-                               ? i18nc("@info:tooltip", "This is the main application language which will be used first, before any other languages.")
-                               : i18nc("@info:tooltip", "This is the language which will be used if any previous languages do not contain a proper translation."));
+    languageButton->setToolTip(
+        primaryLanguage ? i18nc("@info:tooltip", "This is the main application language which will be used first, before any other languages.")
+                        : i18nc("@info:tooltip", "This is the language which will be used if any previous languages do not contain a proper translation."));
 
     int numRows = languagesLayout->rowCount();
 
